@@ -43,14 +43,18 @@ type UI interface {
 
 // Flags define flags accepted by Run
 type Flags struct {
+	Style              Style    `yaml:"style"`
+	Sorting            Sorting  `yaml:"sorting"`
 	CfgFile            string   `yaml:"-"`
 	LogFile            string   `yaml:"log-file"`
 	InputFile          string   `yaml:"input-file"`
 	OutputFile         string   `yaml:"output-file"`
+	IgnoreFromFile     string   `yaml:"ignore-from-file"`
+	StoragePath        string   `yaml:"storage-path"`
 	IgnoreDirs         []string `yaml:"ignore-dirs"`
 	IgnoreDirPatterns  []string `yaml:"ignore-dir-patterns"`
-	IgnoreFromFile     string   `yaml:"ignore-from-file"`
 	MaxCores           int      `yaml:"max-cores"`
+	Top                int      `yaml:"top"`
 	SequentialScanning bool     `yaml:"sequential-scanning"`
 	ShowDisks          bool     `yaml:"-"`
 	ShowApparentSize   bool     `yaml:"show-apparent-size"`
@@ -60,29 +64,27 @@ type Flags struct {
 	ShowItemCount      bool     `yaml:"show-item-count"`
 	ShowMTime          bool     `yaml:"show-mtime"`
 	NoColor            bool     `yaml:"no-color"`
-	NoMouse            bool     `yaml:"no-mouse"`
+	Mouse              bool     `yaml:"mouse"`
 	NonInteractive     bool     `yaml:"non-interactive"`
 	NoProgress         bool     `yaml:"no-progress"`
 	NoUnicode          bool     `yaml:"no-unicode"`
 	NoCross            bool     `yaml:"no-cross"`
 	NoHidden           bool     `yaml:"no-hidden"`
 	NoDelete           bool     `yaml:"no-delete"`
+	NoSpawnShell       bool     `yaml:"no-spawn-shell"`
 	FollowSymlinks     bool     `yaml:"follow-symlinks"`
 	Profiling          bool     `yaml:"profiling"`
 	ConstGC            bool     `yaml:"const-gc"`
 	UseStorage         bool     `yaml:"use-storage"`
-	StoragePath        string   `yaml:"storage-path"`
 	ReadFromStorage    bool     `yaml:"read-from-storage"`
 	Summarize          bool     `yaml:"summarize"`
-	Top                int      `yaml:"top"`
 	UseSIPrefix        bool     `yaml:"use-si-prefix"`
 	NoPrefix           bool     `yaml:"no-prefix"`
 	WriteConfig        bool     `yaml:"-"`
+	ReverseSort        bool     `yaml:"reverse-sort"`
 	ChangeCwd          bool     `yaml:"change-cwd"`
 	DeleteInBackground bool     `yaml:"delete-in-background"`
 	DeleteInParallel   bool     `yaml:"delete-in-parallel"`
-	Style              Style    `yaml:"style"`
-	Sorting            Sorting  `yaml:"sorting"`
 }
 
 // ShouldRunInNonInteractiveMode checks if the application should run in non-interactive mode
@@ -100,12 +102,12 @@ func (f *Flags) ShouldRunInNonInteractiveMode(istty bool) bool {
 
 // Style define style config
 type Style struct {
+	Footer        FooterColorStyle    `yaml:"footer"`
 	SelectedRow   ColorStyle          `yaml:"selected-row"`
+	ResultRow     ResultRowColorStyle `yaml:"result-row"`
+	Header        HeaderColorStyle    `yaml:"header"`
 	ProgressModal ProgressModalOpts   `yaml:"progress-modal"`
 	UseOldSizeBar bool                `yaml:"use-old-size-bar"`
-	Footer        FooterColorStyle    `yaml:"footer"`
-	Header        HeaderColorStyle    `yaml:"header"`
-	ResultRow     ResultRowColorStyle `yaml:"result-row"`
 }
 
 // ProgressModalOpts defines options for progress modal
@@ -147,14 +149,14 @@ type Sorting struct {
 
 // App defines the main application
 type App struct {
-	Args        []string
-	Flags       *Flags
-	Istty       bool
 	Writer      io.Writer
 	TermApp     common.TermApplication
 	Screen      tcell.Screen
 	Getter      device.DevicesInfoGetter
+	Flags       *Flags
 	PathChecker func(string) (fs.FileInfo, error)
+	Args        []string
+	Istty       bool
 }
 
 func init() {
@@ -285,6 +287,7 @@ func (a *App) createUI() (UI, error) {
 			a.Flags.UseSIPrefix,
 			a.Flags.NoPrefix,
 			a.Flags.Top,
+			a.Flags.ReverseSort,
 		)
 		if a.Flags.NoUnicode {
 			stdoutUI.UseOldProgressRunes()
@@ -404,6 +407,11 @@ func (a *App) getOptions() []tui.Option {
 			ui.SetNoDelete()
 		})
 	}
+	if a.Flags.NoSpawnShell {
+		opts = append(opts, func(ui *tui.UI) {
+			ui.SetNoSpawnShell()
+		})
+	}
 	if a.Flags.DeleteInBackground {
 		opts = append(opts, func(ui *tui.UI) {
 			ui.SetDeleteInBackground()
